@@ -6,7 +6,6 @@ from datetime import datetime
 import psutil
 
 from .analyze.pri import LogFile
-from .reporting import abbr_path, phase_str
 from .util import plot_util
 
 
@@ -190,6 +189,16 @@ class Job:
         """
         return self.zLogFile.getPhase
 
+    def isJobStartWithId(self, shortID: str) -> bool:
+        if self.zLogFile.getPlotIdFull.startswith(shortID):
+            return True
+        else:
+            return False
+
+    @property
+    def plot_id(self) -> str:
+        return self.zLogFile.getPlotIdFull
+
     @property
     def plot_id_prefix(self) -> str:
         return self.zLogFile.getPlotIdShort
@@ -321,10 +330,10 @@ def report_jdata(jobs, tmp_prefix='', dst_prefix='') -> list:
             dictionary = {
                 'plotid': j.plot_id_prefix,
                 'k': j.k,
-                'tmp': abbr_path(j.tmpdir, tmp_prefix),
-                'dst': abbr_path(j.dstdir, dst_prefix),
+                'tmp': plot_util.abbr_path(j.tmpdir, tmp_prefix),
+                'dst': plot_util.abbr_path(j.dstdir, dst_prefix),
                 'wall': plot_util.time_format(j.get_time_wall()),
-                'phase': phase_str(j.progress()),
+                'phase': plot_util.phase_str(j.progress()),
                 'tmpdisk': plot_util.human_format(j.get_tmp_usage(), 0),
                 'pid': j.proc.pid,
                 'stat': j.get_run_status(),
