@@ -8,32 +8,19 @@ from . import archive, job, manager, configuration
 from .util import plot_util
 
 
-def abbr_path(path, putative_prefix):
-    if putative_prefix and path.startswith(putative_prefix):
-        return os.path.relpath(path, putative_prefix)
-    else:
-        return path
-
-
-def phase_str(phase_pair):
-    (ph, subph) = phase_pair
-    return ((str(ph) if ph is not None else '?') + ':'
-            + (str(subph) if subph is not None else '?'))
-
-
 def phases_str(phases, max_num=None):
     """
     Take a list of phase-subphase pairs and return them as a compact string
     """
     if not max_num or len(phases) <= max_num:
-        return ' '.join([phase_str(pair) for pair in phases])
+        return ' '.join([plot_util.phase_str(pair) for pair in phases])
     else:
         n_first = math.floor(max_num / 2)
         n_last = max_num - n_first
         n_elided = len(phases) - (n_first + n_last)
-        first = ' '.join([phase_str(pair) for pair in phases[:n_first]])
+        first = ' '.join([plot_util.phase_str(pair) for pair in phases[:n_first]])
         elided = " [+%d] " % n_elided
-        last = ' '.join([phase_str(pair) for pair in phases[n_first + n_elided:]])
+        last = ' '.join([plot_util.phase_str(pair) for pair in phases[n_first + n_elided:]])
         return first + elided + last
 
 
@@ -127,10 +114,10 @@ def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
                 with j.proc.oneshot():
                     row = [j.plot_id_prefix,
                            j.k,
-                           abbr_path(j.tmpdir, tmp_prefix),
-                           abbr_path(j.dstdir, dst_prefix),
+                           plot_util.abbr_path(j.tmpdir, tmp_prefix),
+                           plot_util.abbr_path(j.dstdir, dst_prefix),
                            plot_util.time_format(j.get_time_wall()),
-                           phase_str(j.progress()),
+                           plot_util.phase_str(j.progress()),
                            plot_util.human_format(j.get_tmp_usage(), 0),
                            j.proc.pid,
                            plot_util.human_format(j.get_produced_size(), 1),
@@ -169,7 +156,7 @@ def tmp_dir_report(jobs, dir_cfg, sched_cfg, width, start_row=None, end_row=None
             continue
         phases = sorted(job.job_phases_for_tmpdir(d, jobs))
         ready = manager.phases_permit_new_job(phases, d, sched_cfg, dir_cfg)
-        row = [abbr_path(d, prefix), 'OK' if ready else '--', phases_str(phases)]
+        row = [plot_util.abbr_path(d, prefix), 'OK' if ready else '--', phases_str(phases)]
         tab.add_row(row)
 
     tab.set_max_width(width)
@@ -198,7 +185,7 @@ def dst_dir_report(jobs, dstdirs, width, prefix=''):
 
         priority = archive.compute_priority(eldest_ph, gb_free, n_plots)
 
-        row = [abbr_path(d, prefix), n_plots, gb_free,
+        row = [plot_util.abbr_path(d, prefix), n_plots, gb_free,
                phases_str(phases, 5), priority]
 
         tab.add_row(row)
@@ -209,7 +196,7 @@ def dst_dir_report(jobs, dstdirs, width, prefix=''):
 
 
 def arch_dir_report(archdir_freebytes, width, prefix=''):
-    cells = ['%s:%5dGB' % (abbr_path(d, prefix), int(int(space) / plot_util.GB))
+    cells = ['%s:%5dGB' % (plot_util.abbr_path(d, prefix), int(int(space) / plot_util.GB))
              for (d, space) in sorted(archdir_freebytes.items())]
     if not cells:
         return ''
@@ -255,10 +242,10 @@ def jsondata(jobs, tmp_prefix='', dst_prefix='') -> list:
             dictionary = {
                 'plotid': j.plot_id_prefix,
                 'k': j.k,
-                'tmp': abbr_path(j.tmpdir, tmp_prefix),
-                'dst': abbr_path(j.dstdir, dst_prefix),
+                'tmp': plot_util.abbr_path(j.tmpdir, tmp_prefix),
+                'dst': plot_util.abbr_path(j.dstdir, dst_prefix),
                 'wall': plot_util.time_format(j.get_time_wall()),
-                'phase': phase_str(j.progress()),
+                'phase': plot_util.phase_str(j.progress()),
                 'tmpdisk': plot_util.human_format(j.get_tmp_usage(), 0),
                 'pid': j.proc.pid,
                 'stat': j.get_run_status(),
